@@ -15,7 +15,6 @@ from starpack.errors import *
 
 
 class StarpackClient:
-
     volumes: Dict[str, Dict[str, str]] = {
         "artifacts": {
             "host": "starpack-model-artifacts",
@@ -72,7 +71,19 @@ class StarpackClient:
         output = requests.post(deploy_url, json=payload)
 
         if output.status_code / 100 == 2:
-            print(f"Successfully deployed {payload['deployment']['metadata']['name']}")
+            endpoints = output.json().get("endpoints")
+            deployment_name = payload["deployment"]["metadata"]["name"]
+            if not endpoints:
+                print(
+                    f"Deployed {deployment_name} at an unknown location. "
+                    f"Please check Docker to find your running container."
+                )
+            else:
+                for wrapper, url in endpoints.items():
+                    print(
+                        f"Deployed {deployment_name} using wrapper {wrapper} at {url}."
+                    )
+
         else:
             print(output.status_code)
             print(output.text)
@@ -128,7 +139,8 @@ class StarpackClient:
         self.docker_client.volumes.create(
             name=self.volumes["artifacts"]["host"], labels={"app": self.app_label}
         )
-        self.docker_client.images.pull(settings.engine_image)
+        if settings.pull_image:
+            self.docker_client.images.pull(settings.engine_image)
 
         print(f"Starting Starpack Engine at {self.url}")
         self.engine = self.docker_client.containers.run(
